@@ -95,7 +95,7 @@ class ServiceDesk(AtlassianRestAPI):
         :param request_participants: list
         :return: New request
         """
-        log.warning("Creating request...")
+        log.info("Creating request...")
         data = {
             "serviceDeskId": service_desk_id,
             "requestTypeId": request_type_id,
@@ -242,18 +242,37 @@ class ServiceDesk(AtlassianRestAPI):
 
         return self.post(path=url, data=data, headers=self.experimental_headers)
 
-    def get_request_comments(self, issue_id_or_key):
+    def get_request_comments(self, issue_id_or_key, start=0, limit=50, public=True, internal=True):
         """
         Get all comments in issue
 
         :param issue_id_or_key: str
+        :param start: OPTIONAL: int
+        :param limit: OPTIONAL: int
+        :param public: OPTIONAL: bool
+        :param internal: OPTIONAL: bool
         :return: Issue comments
         """
+        url = "rest/servicedeskapi/request/{}/comment".format(issue_id_or_key)
+        params = {}
+        if start is not None:
+            params["start"] = int(start)
+        if limit is not None:
+            params["limit"] = int(limit)
+        if public is not None:
+            params["public"] = bool(public)
+        if internal is not None:
+            params["internal"] = bool(internal)
 
-        return self.get(
-            "rest/servicedeskapi/request/{}/comment".format(issue_id_or_key),
-            headers=self.experimental_headers,
-        )
+        response = self.get(url, params=params, headers=self.experimental_headers)
+        if self.advanced_mode:
+            return response
+        return (response or {}).get("values")
+
+        # return self.get(
+        #     "rest/servicedeskapi/request/{}/comment".format(issue_id_or_key),
+        #     headers=self.experimental_headers,
+        # )
 
     def get_request_comment_by_id(self, issue_id_or_key, comment_id):
         """
